==> openvdb-10.0.1-4-aarch64.pkg.tar.xz: usr/share/doc/OpenVDB/html/search/enumvalues_d.js <==
var searchData=
[
  ['o0_0',['O0',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a7e6bfed55985b52e9dbfc6df8f291186',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['o1_1',['O1',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a00594a175ce5a58f286d91ca0a6f15a2',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['o2_2',['O2',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28abfc60714f62f15e1e72e0b21454cc99e',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['o3_3',['O3',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a9ee25ee8b4d0a573527fcd2f1e73f8c8',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['off_4',['OFF',['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#ade0a25d0d6ba0e0a4d939aedcbb8fae0a88559a0cfd8250c9d65970cc145c92d4',1,'openvdb::v10_0::ax::VolumeExecutable::OFF()'],['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#af607f22e4873b3369e942d9ebb3e72b1a88559a0cfd8250c9d65970cc145c92d4',1,'openvdb::v10_0::ax::VolumeExecutable::OFF()']]],
  ['on_5',['ON',['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#ade0a25d0d6ba0e0a4d939aedcbb8fae0a90651ebea9a35ec4e018c8157492e17c',1,'openvdb::v10_0::ax::VolumeExecutable::ON()'],['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#af607f22e4873b3369e942d9ebb3e72b1a90651ebea9a35ec4e018c8157492e17c',1,'openvdb::v10_0::ax::VolumeExecutable::ON()']]],
  ['openvdb_5ffile_5fversion_5fblosc_5fcompression_6',['OPENVDB_FILE_VERSION_BLOSC_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea734c8591d73ade4e36928409a6c8781f',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fbool_5fleaf_5foptimization_7',['OPENVDB_FILE_VERSION_BOOL_LEAF_OPTIMIZATION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea39944ff09038abccb66cb4734bb04b76',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fboost_5fuuid_8',['OPENVDB_FILE_VERSION_BOOST_UUID',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea92530ad33f099f8f49b3db20fcd63d0c',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5ffloat_5ffrustum_5fbbox_9',['OPENVDB_FILE_VERSION_FLOAT_FRUSTUM_BBOX',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea9f0a34f01c923448692ebab6fc8157ea',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fgrid_5finstancing_10',['OPENVDB_FILE_VERSION_GRID_INSTANCING',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea5b1955bdc7bfb97200c01693499d86ed',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5finternalnode_5fcompression_11',['OPENVDB_FILE_VERSION_INTERNALNODE_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceaa0ba864e79bace97c0ff5d303c85e062',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fmultipass_5fio_12',['OPENVDB_FILE_VERSION_MULTIPASS_IO',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceabd22e40f4f1d7ff4adf3ab36392a6799',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fnew_5ftransform_13',['OPENVDB_FILE_VERSION_NEW_TRANSFORM',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceacf27fdeb27c14dd0fa37afaa9e860943',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fno_5fgridmap_14',['OPENVDB_FILE_VERSION_NO_GRIDMAP',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceabe6c412205fd80009e7e0c9612de53dd',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fnode_5fmask_5fcompression_15',['OPENVDB_FILE_VERSION_NODE_MASK_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea71883b4156db5731c39d342a04e79e5a',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fpoint_5findex_5fgrid_16',['OPENVDB_FILE_VERSION_POINT_INDEX_GRID',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceaeef748e6dd4df219116923abd299dffa',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5frootnode_5fmap_17',['OPENVDB_FILE_VERSION_ROOTNODE_MAP',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceaba32c7339fc3df797f72fbfe2a0cc136',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fselective_5fcompression_18',['OPENVDB_FILE_VERSION_SELECTIVE_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea4f68b777de5275a442ac62582cec2754',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fsimplified_5fgrid_5ftypename_19',['OPENVDB_FILE_VERSION_SIMPLIFIED_GRID_TYPENAME',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceab9c004ca1c701249a07a6ea2e0f7943c',1,'openvdb::v10_0']]],
  ['or_20',['OR',['../namespaceopenvdb_1_1v10__0_1_1ax_1_1ast_1_1tokens.html#a2917ae141bdf0c0be0d6eb1480f09f8aa96727447c0ad447987df1c6415aef074',1,'openvdb::v10_0::ax::ast::tokens::OR()'],['../axparser_8h.html#a4fb17c3afc02be01e847b79146e4a6e6a96727447c0ad447987df1c6415aef074',1,'OR():&#160;axparser.h']]],
  ['os_21',['Os',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a02c4b2dc4fd2ac7e8bbde8e46adce723',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['oz_22',['Oz',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a0adaeee8e8df29fe501cf3e675ebde70',1,'openvdb::v10_0::ax::CompilerOptions']]]
];

==> openvdb-10.0.1-5-aarch64.pkg.tar.xz: usr/share/doc/OpenVDB/html/search/enumvalues_d.js <==
var searchData=
[
  ['o0_0',['O0',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a7e6bfed55985b52e9dbfc6df8f291186',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['o1_1',['O1',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a00594a175ce5a58f286d91ca0a6f15a2',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['o2_2',['O2',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28abfc60714f62f15e1e72e0b21454cc99e',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['o3_3',['O3',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a9ee25ee8b4d0a573527fcd2f1e73f8c8',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['off_4',['off',['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#ade0a25d0d6ba0e0a4d939aedcbb8fae0a88559a0cfd8250c9d65970cc145c92d4',1,'openvdb::v10_0::ax::VolumeExecutable::OFF'],['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#af607f22e4873b3369e942d9ebb3e72b1a88559a0cfd8250c9d65970cc145c92d4',1,'openvdb::v10_0::ax::VolumeExecutable::OFF']]],
  ['on_5',['on',['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#ade0a25d0d6ba0e0a4d939aedcbb8fae0a90651ebea9a35ec4e018c8157492e17c',1,'openvdb::v10_0::ax::VolumeExecutable::ON'],['../classopenvdb_1_1v10__0_1_1ax_1_1VolumeExecutable.html#af607f22e4873b3369e942d9ebb3e72b1a90651ebea9a35ec4e018c8157492e17c',1,'openvdb::v10_0::ax::VolumeExecutable::ON']]],
  ['openvdb_5ffile_5fversion_5fblosc_5fcompression_6',['OPENVDB_FILE_VERSION_BLOSC_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea734c8591d73ade4e36928409a6c8781f',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fbool_5fleaf_5foptimization_7',['OPENVDB_FILE_VERSION_BOOL_LEAF_OPTIMIZATION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea39944ff09038abccb66cb4734bb04b76',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fboost_5fuuid_8',['OPENVDB_FILE_VERSION_BOOST_UUID',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea92530ad33f099f8f49b3db20fcd63d0c',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5ffloat_5ffrustum_5fbbox_9',['OPENVDB_FILE_VERSION_FLOAT_FRUSTUM_BBOX',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea9f0a34f01c923448692ebab6fc8157ea',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fgrid_5finstancing_10',['OPENVDB_FILE_VERSION_GRID_INSTANCING',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea5b1955bdc7bfb97200c01693499d86ed',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5finternalnode_5fcompression_11',['OPENVDB_FILE_VERSION_INTERNALNODE_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceaa0ba864e79bace97c0ff5d303c85e062',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fmultipass_5fio_12',['OPENVDB_FILE_VERSION_MULTIPASS_IO',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceabd22e40f4f1d7ff4adf3ab36392a6799',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fnew_5ftransform_13',['OPENVDB_FILE_VERSION_NEW_TRANSFORM',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceacf27fdeb27c14dd0fa37afaa9e860943',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fno_5fgridmap_14',['OPENVDB_FILE_VERSION_NO_GRIDMAP',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceabe6c412205fd80009e7e0c9612de53dd',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fnode_5fmask_5fcompression_15',['OPENVDB_FILE_VERSION_NODE_MASK_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea71883b4156db5731c39d342a04e79e5a',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fpoint_5findex_5fgrid_16',['OPENVDB_FILE_VERSION_POINT_INDEX_GRID',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceaeef748e6dd4df219116923abd299dffa',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5frootnode_5fmap_17',['OPENVDB_FILE_VERSION_ROOTNODE_MAP',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceaba32c7339fc3df797f72fbfe2a0cc136',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fselective_5fcompression_18',['OPENVDB_FILE_VERSION_SELECTIVE_COMPRESSION',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fcea4f68b777de5275a442ac62582cec2754',1,'openvdb::v10_0']]],
  ['openvdb_5ffile_5fversion_5fsimplified_5fgrid_5ftypename_19',['OPENVDB_FILE_VERSION_SIMPLIFIED_GRID_TYPENAME',['../namespaceopenvdb_1_1v10__0.html#aaf105ae5beaca1dee30ae54530691fceab9c004ca1c701249a07a6ea2e0f7943c',1,'openvdb::v10_0']]],
  ['or_20',['or',['../namespaceopenvdb_1_1v10__0_1_1ax_1_1ast_1_1tokens.html#a2917ae141bdf0c0be0d6eb1480f09f8aa96727447c0ad447987df1c6415aef074',1,'openvdb::v10_0::ax::ast::tokens::OR'],['../axparser_8h.html#a4fb17c3afc02be01e847b79146e4a6e6a96727447c0ad447987df1c6415aef074',1,'OR:&#160;axparser.h']]],
  ['os_21',['Os',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a02c4b2dc4fd2ac7e8bbde8e46adce723',1,'openvdb::v10_0::ax::CompilerOptions']]],
  ['oz_22',['Oz',['../structopenvdb_1_1v10__0_1_1ax_1_1CompilerOptions.html#a43f71430e3b7055e1ce934fd6fba4c28a0adaeee8e8df29fe501cf3e675ebde70',1,'openvdb::v10_0::ax::CompilerOptions']]]
];
